import React, { useState, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { getTarget } from '@s-ui/js/lib/react';
var BASE_CLASS = 'sui-AtomBackToTop';
var CLASS_ICON = BASE_CLASS + "-icon";
var CLASS_TEXT = BASE_CLASS + "-text";
var CLASS_SHOW = BASE_CLASS + "--show";
var CLASS_HIDE = BASE_CLASS + "--hide";
var CLASS_HOVER = CLASS_SHOW + "--hover";
var CLASS_READY = BASE_CLASS + "--ready";
var STYLES = {
  DARK: 'dark',
  LIGHT: 'light'
};

var AtomBackToTop = function AtomBackToTop(_ref) {
  var IconTop = _ref.iconTop,
      minHeight = _ref.minHeight,
      textTop = _ref.textTop,
      _ref$scrollSteps = _ref.scrollSteps,
      scrollSteps = _ref$scrollSteps === void 0 ? 100 : _ref$scrollSteps,
      _ref$scrollIntervalTi = _ref.scrollIntervalTime,
      scrollIntervalTime = _ref$scrollIntervalTi === void 0 ? 50 : _ref$scrollIntervalTi,
      _ref$refContainer = _ref.refContainer,
      refContainer = _ref$refContainer === void 0 ? document.body : _ref$refContainer,
      _ref$style = _ref.style,
      style = _ref$style === void 0 ? STYLES.DARK : _ref$style;

  var _useState = useState(false),
      show = _useState[0],
      setShow = _useState[1];

  var _useState2 = useState(false),
      hover = _useState2[0],
      setHover = _useState2[1];

  var intervalRef = useRef();
  useEffect(function () {
    var container = getTarget(refContainer);

    var handleScroll = function handleScroll() {
      var scrollTop = container.scrollTop,
          scrollHeight = container.scrollHeight,
          clientHeight = container.clientHeight;
      var halfHeight = Math.floor((scrollHeight - clientHeight) / 2);

      if (scrollTop > halfHeight || scrollTop > minHeight) {
        if (!show) {
          setShow(true);
        }
      } else {
        if (show) {
          setShow(false);
          setHover(false);
        }
      }
    };

    container.removeEventListener('scroll', handleScroll);
    container.addEventListener('scroll', handleScroll);
    return function () {
      container.removeEventListener('scroll', handleScroll);
    };
  }, [minHeight, refContainer, show]);

  var scrollStep = function scrollStep() {
    var container = getTarget(refContainer);
    var scrollTop = container.scrollTop;
    var intervalId = intervalRef.current;
    if (scrollTop === 0) clearInterval(intervalId);
    if (scrollTop) container.scrollTop = scrollTop - scrollSteps;
  };

  var scrollToTop = function scrollToTop() {
    var intervalId = setInterval(scrollStep, scrollIntervalTime);
    intervalRef.current = intervalId;
  };

  var hoverButton = function hoverButton() {
    return setHover(true);
  };

  var unhoverButton = function unhoverButton() {
    return setHover(false);
  };

  return React.createElement("button", {
    title: "Back to top",
    className: cx(BASE_CLASS, BASE_CLASS + "--" + style, show !== null && CLASS_READY, show ? CLASS_SHOW : CLASS_HIDE, hover && CLASS_HOVER),
    onMouseOver: hoverButton,
    onMouseOut: unhoverButton,
    onClick: scrollToTop
  }, IconTop && React.createElement("span", {
    className: CLASS_ICON
  }, React.createElement(IconTop, null)), textTop && React.createElement("span", {
    className: CLASS_TEXT
  }, textTop));
};

AtomBackToTop.displayName = 'AtomBackToTop';
export { STYLES as backToTopStyles };
export default AtomBackToTop;